==> dl.php?src=linea21_1_6.zip: linea21/templates/public/default/index.php <==
<?php
/**
 * @package linea21.templates
 * @subpackage public
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
echo '<?xml version="1.0" encoding="'.CHARSET.'" xml:lang="'.U_L.'"?>'.END_LINE;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo U_L; ?>">
<?php distInclude(THEME_PUBLIC_PATH.'header.php', THEME_PUBLIC_DIST); ?>
<body>
<?php culture::getInstance()->renderSwitcher(); ?>
<div id="header">
  <img src="<?php echo THEME_PUBLIC_PATH; ?>images/logo.png" alt="<?php echo (SITE_NAME); ?>" />
  <h1><?php echo (SITE_NAME); ?></h1>
</div><!-- End Header -->

<div id="menu">
  <?php echo DisplayMenu(); ?>
</div> <!-- End Menu -->

<div id="content" class="section_<?php echo ActiveItemKey($GLOBALS['activeitem']); ?> alias_<?php echo ActiveItemAlias($GLOBALS['activeitem']);?> <?php echo getItemId(); ?>">
  <div id="main-container">##BREADCRUMB##
  <div id="main"><!-- Begin Page -->
  	<div id="printer">
  		<a href="javascript:self.print();" class="print button" title="<?php echo _t('divers','print'); ?>"><span><?php echo _t('divers','print'); ?></span></a>
    </div>
    <?php DisplayTemplate(); ?>
  </div> <!-- End Page -->
  <hr class="spacer" />
  </div> <!-- End Main -->

  <div id="sidebar">
    <?php distInclude(THEME_PUBLIC_PATH.'sidebar.php', THEME_PUBLIC_DIST); ?>
  </div> <!-- End Sidebar -->
</div> <!-- End Content -->

<!-- Footer -->
<div id="footer"><?php displayDefaultFooter(); ?>
  <p>Linea21 (v <?php echo LINEA_VERSION; ?>), <?php printf(_t('divers','licence') ,'<a href="http://opensource.org/licenses/gpl-3.0.html" title="GNU GPL v3" class="out">GNU GPL v3</a>'); ?></p>
  <?php if(isset($_SESSION['authenticated']) && !$l21auth->isSimpleUser())  { ?>
  	<a href="../admin/index.php" title="<?php echo _t('header','title');?>"><?php echo _t('header','title');?></a>
  <?php  } ?>
</div>
<!-- End Footer -->
<?php AddDynamicFooter(); ?>
<?php if(isset($Dbg)) $Dbg->display(); ?>
</body>
</html>

==> dl.php?src=linea21_1_7.zip: linea21/templates/public/default/index.php <==
<?php
/**
 * @package linea21.templates
 * @subpackage public
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
include_once('../class/class.page.php');
include_once(override('../page/display.php'));
include_once(override('../page/'.SQL.'.inc.php'));
echo '<?xml version="1.0" encoding="'.CHARSET.'" xml:lang="'.U_L.'"?>'.END_LINE;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo U_L; ?>">
<?php distInclude(THEME_PUBLIC_PATH.'header.php', THEME_PUBLIC_DIST); ?>
<body>
<?php culture::getInstance()->renderSwitcher(); ?>
<div id="header">
  <img src="<?php echo THEME_PUBLIC_PATH; ?>images/logo.png" alt="<?php echo (SITE_NAME); ?>" />
  <h1><?php echo (SITE_NAME); ?></h1>
</div><!-- End Header -->

<div id="menu">
  <?php echo DisplayMenu(); ?>
</div> <!-- End Menu -->

<div id="content" class="section_<?php echo ActiveItemKey($GLOBALS['activeitem']); ?> alias_<?php echo ActiveItemAlias($GLOBALS['activeitem']);?> <?php echo getItemId(); ?>">
  <div id="main-container">##BREADCRUMB##
  <div id="main"><!-- Begin Page -->
  	<div id="printer">
  		<a href="javascript:self.print();" class="print button" title="<?php echo _t('divers','print'); ?>"><span><?php echo _t('divers','print'); ?></span></a>
    </div>
    <?php DisplayTemplate(); ?>
  </div> <!-- End Page -->
  <hr class="spacer" />
  </div> <!-- End Main -->

  <div id="sidebar">
    <?php distInclude(THEME_PUBLIC_PATH.'sidebar.php', THEME_PUBLIC_DIST); ?>
  </div> <!-- End Sidebar -->
</div> <!-- End Content -->

<!-- Footer -->
<div id="footer"><?php displayDefaultFooter(); ?>
  <p>Linea21 (v <?php echo LINEA_VERSION; ?>), <?php printf(_t('divers','licence') ,'<a href="http://opensource.org/licenses/gpl-3.0.html" title="GNU GPL v3" class="out">GNU GPL v3</a>'); ?></p>
  <?php if(isset($_SESSION['authenticated']) && !$l21auth->isSimpleUser())  { ?>
  	<a href="../admin/index.php" title="<?php echo _t('header','title');?>"><?php echo _t('header','title');?></a>
  <?php  } ?>
</div>
<!-- End Footer -->
<?php AddDynamicFooter(); ?>
<?php if(isset($Dbg)) $Dbg->display(); ?>
</body>
</html>
